@@ -5,7 +5,12 @@ invert4geom: Constrained gravity inversion to recover the geometry of a density
 contrast.
 """
 
-
 from __future__ import annotations
 
-__version__ = "0.1.20"
+__version__ = "0.9.1"
+
+import logging
+
+log = logging.getLogger(__name__)
+
+log.addHandler(logging.NullHandler())
